@@ -55,8 +55,20 @@ class ModelDiffTestCase(TestCase):
 
     def test_jsonfield_change(self):
         tm = TestDiff(a_json_field={"hi": "bye"})
+        tm_2 = TestDiff(a_json_field={'beep': 'boop'})
         tm.save()
+        tm_2.save()
         self.assertFalse(tm.has_changed)
+        self.assertFalse(tm_2.has_changed)
+
+        # Change a single field, should be marked as having changed
+        tm.a_json_field['hi'] = 'OH YEAH!'
+
+        # Ditto for setting a brand-new dict
+        tm_2.a_json_field = {'beep': 'bloop'}
+
+        self.assertTrue(tm.has_changed)
+        self.assertTrue(tm_2.has_changed)
 
     def test_is_creation(self):
         tm = TestDiff.objects.create(name="New Thing")
